@@ -247,14 +247,14 @@ def delete_dir_content(path):
 
 def delete_dirs(*paths):
     """
-    Alias for delete_dirs.
+    Alias for remove_dirs.
     """
     remove_dirs(*paths)
 
 
 def delete_file(path):
     """
-    Alias for delete_file.
+    Alias for remove_file.
     """
     removed = remove_file(path)
     return removed
@@ -262,7 +262,7 @@ def delete_file(path):
 
 def delete_files(*paths):
     """
-    Alias for delete_files.
+    Alias for remove_files.
     """
     remove_files(*paths)
 
@@ -482,6 +482,13 @@ def get_filename(path):
     return filename
 
 
+def get_parent_dir(path, levels=1):
+    """
+    Get the parent directory for the given path going up N levels.
+    """
+    return join_path(path, *([os.pardir] * max(1, levels)))
+
+
 def is_dir(path):
     """
     Determine whether the specified path represents an existing directory.
@@ -535,8 +542,7 @@ def join_filepath(dirpath, filename):
     """
     Create a filepath joining the directory path and the filename.
     """
-    filepath = os.path.join(dirpath, filename)
-    return filepath
+    return join_path(dirpath, filename)
 
 
 def join_path(path, *paths):
@@ -548,7 +554,8 @@ def join_path(path, *paths):
     basepath = path
     if get_file_extension(path) in ['py', 'pyc', 'pyo']:
         basepath = os.path.dirname(os.path.realpath(path))
-    return os.path.join(basepath, *paths)
+    paths = [path.lstrip(os.sep) for path in paths]
+    return os.path.normpath(os.path.join(basepath, *paths))
 
 
 def list_dirs(path):
